import { OpenAPI3 } from 'openapi-typescript';
import * as pj from 'projen';
export interface RestApiOptions {
    readonly apiName: string;
    readonly definitionFile: string;
}
/**
 * The RestApi construct sets up an OpenAPI-based REST API for a serverless project using projen.
 * This construct extends the projen Component to include dependencies and development dependencies required for OpenAPI and AWS Lambda,
 * and provides methods to generate TypeScript types from the OpenAPI definition file. It also generates sample handler files for the API endpoints.
 *
 * @example
 * const restApi = new RestApi(app, {
 *   apiName: 'MyRestApi',
 *   definitionFile: 'src/openapi/schema.yaml',
 * });
 */
export declare class RestApi extends pj.Component {
    protected options: RestApiOptions;
    /**
     * Creates an instance of RestApi.
     *
     * @param app - The AWS CDK TypeScript app.
     * @param options - The options for configuring the RestApi.
     */
    constructor(app: pj.awscdk.AwsCdkTypeScriptApp, options: RestApiOptions);
    /**
     * Creates the construct file content for the generated REST API.
     *
     * @param file - The file object to create content for.
     * @returns The content of the construct file.
     */
    protected createConstructFile(file: pj.FileBase): string;
    /**
     * Validates a path reference in the OpenAPI specification.
     *
     * @param apiSpec - The OpenAPI specification object.
     * @param path - The path reference to validate.
     * @param visited - The list of visited paths to detect cycles.
     * @returns True if the path reference is valid, otherwise false.
     * @throws If the path reference is invalid or cyclical.
     */
    protected validatePathRef(apiSpec: OpenAPI3, path: string, visited?: string[]): boolean;
    /**
     * Adds a sample handler file for a REST API resource.
     *
     * @param files - The collection of file generators.
     * @param apiSpec - The OpenAPI specification object.
     * @param path - The path of the API resource.
     * @param method - The HTTP method of the API resource.
     */
    protected addRestResourceHandlerSample(files: {
        [fileName: string]: () => string;
    }, apiSpec: OpenAPI3, path: string, method: string): void;
    /**
     * Creates the entry file content for a REST API handler.
     *
     * @param method - The HTTP method of the API resource.
     * @param operationId - The operation ID of the API resource.
     * @returns The content of the entry file.
     */
    protected createEntryFile(method: string, operationId: string): string;
    /**
     * Generates sample handler files for the REST API based on the OpenAPI specification.
     *
     * @returns The collection of file generators for the sample handler files.
     */
    private generateSampleHandlerFiles;
}
